@@ -9,7 +9,7 @@ from .lc_option import LcOption
 TARGET_RE = r'"pics":(.*)\}\}'
 PIC_HOST = 'https://tva1.sinaimg.cn/'
 SIZES = 'large|bmiddle|mw1024|mw690|small|square|thumb180|thumbnail'.split('|')
-API_URL = 'https://picupload.weibo.com/interface/pic_upload.php?ori=1&data=%s&mime=image%2F%s'
+API_URL = 'https://picupload.weibo.com/interface/pic_upload.php?ori=1&data={}&mime=image%2F{}'
 
 
 class Weibo:
@@ -71,7 +71,7 @@ class Weibo:
         elif mode == 'base64':
             filep = source
             files = {'b64_data': filep}
-        url = API_URL.format(mode, 'jpeg', fmt)
+        url = API_URL.format(mode, fmt)
         res = requests.post(url, files=files, headers=self.headers)
         html = res.text
 
